from tkinter.filedialog import askopenfilename
import matplotlib.pyplot as plt
from numpy import loadtxt

# Ouverture en mode graphique d'un fichier de pointage au format CSV
# Ne pas modifier les lignes 7 à 17

# on peut donner le chemin d'accès vers le fichier ou la fonction askopenfilename
name = askopenfilename(filetypes=(("Fichier CSV", "*.csv"), ("Fichier Texte",
                                                             "*.txt"), ("Tous les fichiers", "*.*")), title="Choisir un fichier")

# name contient le chemin et le nom du fichier à traiter.
# On importe les valeurs de la date t, de l'abscisse x et de l'ordonnée y dans trois listes.
t, x, y = loadtxt(name, skiprows=1, delimiter=";",
                  unpack=True, usecols=(0, 1, 2))

# On dispose à ce stade des trois listes contenant les coordonnées du ballon.

dt = t[1] - t[0]  # Détermination de l'intervalle de temps entre deux pointages

# Calcul des coordonnées des vecteurs vitesse
"""Complétez les champs indiqués afin de calculer :
    - les coordonnées vx et vy au point n°i avec les instants encadrant le point i
    - les coordonnnées Dvx et Dvy au point n°i avec la même méthode"""

# Calcul des coordonnées des vecteurs vitesse instantanée sous forme de listes en compréhension

vx = [(x[i+1] - x[i-1]) / (2 * dt) for i in range(1, len(t) - 1)]

vy = [(y[i+1] - y[i-1]) / (2 * dt) for i in range(1, len(t) - 1)]

# Calcul des coordonnées des vecteurs variation de vitesse sous forme de listes en compréhension

Dvx = [vx[i+1] - vx[i-1] for i in range(1, len(vx) - 1)]

Dvy = [vy[i+1] - vy[i-1] for i in range(1, len(vy) - 1)]

# Tracé des vecteurs : ajuster les valeurs du paramètre scale pour changer la taille des vecteurs
# Plus la valeur est faible, plus le vecteur est long

# On trace sur une figure les vecteurs vitesse instantanée

plt.figure(1)
plt.title(
    "Vecteurs vitesse instantanée sur les pointages réalisés (échelle arbitraire)")
plt.scatter(x, y, marker="x", color="blue", label="Positions")
"""Pour une figure plus lisible, on ne trace qu'un vecteur sur deux"""

v = plt.quiver(x[1:-1:], y[1:-1:], vx[::], vy[::], units="dots",
               color="red", scale=0.04, label="Vecteurs vitesse instantanée")

"""La ligne ci-dessous trace une échelle de représentation
echelleV contient la valeur du vecteur échelle."""
echelleV = 2.  # 2 m/s pour le vecteur échelle
# plt.quiverkey(v, 0.85, 0.8, echelleV, coordinates="axes", label=f"{echelleV:.1f} m/s")
plt.axis("equal")
plt.xlabel("x (m)")
plt.ylabel("y (m)")
plt.legend()
plt.show()

# On trace sur une figure les vecteurs variation de vitesse
plt.figure(2)
plt.title(
    "Vecteurs variation de vitesse sur les pointages réalisés (échelle arbitraire)")
plt.scatter(x, y, marker="x", color="blue", label="Positions")
Dv = plt.quiver(x[2:-2:], y[2:-2:], Dvx, Dvy, units="dots", scale=0.005,
                color="green", label="Vecteurs variation de vitesse")

"""La ligne ci-dessous trace une échelle de représentation
echelleDV contient la valeur du vecteur échelle."""
echelleDV = 0.5  # 0.5 m/s pour cet exemple
# plt.quiverkey(Dv, 0.85, 0.8, echelleDV, coordinates="axes", label=f"{echelleDV:.1f} m/s")
plt.axis("equal")
plt.xlabel("x (m)")
plt.ylabel("y (m)")
plt.legend()
plt.show()
