# Ce programme permet d'obtenir les variations des énergies potentielle, cinétique
# et mécanique au cours du temps à partir d'un fichier csv contenant les positions
# x et y au cours du temps (obtenu par un pointage sur une vidéo)
# Les zones marquées À COMPLÉTER attendent que vous entriez les valeurs ou expressions correctes.

from tkinter.filedialog import askopenfilename
import matplotlib.pyplot as plt
from numpy import loadtxt, mean

# Ouverture en mode graphique d'un fichier de pointage au format CSV
# Ne pas modifier les lignes 7 à 17

# on peut donner le chemin d'accès vers le fichier ou la fonction askopenfilename
name = askopenfilename(filetypes=(("Fichier CSV", "*.csv"), ("Fichier Texte",
                                                             "*.txt"), ("Tous les fichiers", "*.*")), title="Choisir un fichier")

# name contient le chemin et le nom du fichier à traiter.
# On importe les valeurs de la date t, de l'abscisse x et de l'ordonnée y dans trois listes.
t, x, y = loadtxt(name, skiprows=1, delimiter=";",
                  unpack=True, usecols=(0, 1, 2))

# On dispose à ce stade des trois listes contenant les coordonnées du ballon.

dt = t[1] - t[0]  # Détermination de l'intervalle de temps entre deux pointages

# FIN D'IMPORTATION DES DONNÉES DE POSITION

# Saisie au clavier de la masse de la balle
m = float(input("Entrez la masse de l'objet en kg : "))
g = 9.8  # intensité de la pesanteur
dt = t[1] - t[0]  # Calcul de l'intervalle de temps entre deux pointages

"""Calcul des coordonnées des vecteurs vitesse
Compléter les zones indiquées en adaptant en Python les relations données dans
la description de l'activité"""

# la vitesse n'est pas calculable à la première et à la dernière position
vx = [(x[i+1] - x[i-1]) / (2 * dt) for i in range(1, len(t)-1)]
vy = [(y[i+1] - y[i-1]) / (2 * dt)
      for i in range(1, len(t)-1)]  # même remarque
v = [(vx[i]**2 + vy[i]**2)**0.5 for i in range(len(vx))]

"""Calcul des énergies
Compléter les zones indiquées en adaptant en Python les relatiosn données dans
la description de l'activité"""

# y[1:-1:] : on ne calcule pas pour la première et la dernière position
Ep = [m * g * val for val in y[1:-1:]]
Ec = [0.5 * m * val**2 for val in v]
Em = [Ep[i] + Ec[i] for i in range(len(Ep))]
Emmoy = mean(Em)
Emoyen = [Emmoy for i in range(len(Ep))]

# Calcul des coordonnées des vecteurs variation de vitesse
"""Les listes en abscisses et ordonnées doivent avoir les mêmes dimensions :
    on supprime la première et la dernière date de la liste t"""

plt.close()
plt.plot(t[1:-1:], Ep, "b+", ms=10, label="Énergie potentielle")
plt.plot(t[1:-1:], Ec, "r+", ms=10, label="Énergie cinétique")
plt.plot(t[1:-1:], Em, "g+", ms=10, label="Énergie mécanique")
"""plt.plot(t[1:-1:], Emoyen, "k--", ms=20,
         label="Valeur moyenne de l'énergie mécanique")"""
plt.title("Évolution des énergies au cours du temps")
plt.xlabel("t (s)")
plt.ylabel("Énergies en J")
plt.grid()
plt.legend()
plt.show()

# print(f"Distance parcourue {x[-2] - x[0]:.3f} m")
