# Ce programme permet d'obtenir les variations des énergies potentielle, cinétique
# et mécanique au cours du temps à partir d'un fichier csv contenant les positions
# x et y au cours du temps (obtenu par un pointage sur une vidéo)
# Les zones marquées À COMPLÉTER attendent que vous entriez les valeurs ou expressions correctes.

# IMPORTATION DES BIBLIOTHÈQUES NÉCESSAIRES

from tkinter.filedialog import askopenfilename
import matplotlib.pyplot as plt

#on peut donner le chemin d'accès vers le fichier ou la fonction askopenfilename
name = askopenfilename(filetypes =(("Fichier CSV", "*.csv"),("Fichier Texte","*.txt"),("Tous les fichiers","*.*")),title = "Choisir un fichier")

sep = ";" #caractère séparateur du csv -peut être une virgule, un point-virgule ou une tabulation noté \t 
entete = 1 #nombre de lignes d'entete

f = open(name,"r")
data = f.readlines() #on lit toutes les lignes et on met ça dans une liste -un élément par ligne-
f.close() #on referme le fichier

data = data[ entete : ] #on supprime les lignes d'en-tête qui ne nous intéressent pas

#on construit les listes de valeurs utiles
t = []
x = []
y = []

for ligne in data:
    ligne = ligne.replace("," , ".") #change les virgules en point => format numérique différent sur excel et sur python
    ligne = ligne.strip().split(sep) #on sépare les différents élément en utilisant le caractère séparateur défini
    ligne = list(map(float,ligne)) #on converti chaque élément en flottant

    #on rentre les valeurs dans les lites adaptées
    t.append(ligne[0]) 
    x.append(ligne[1])
    y.append(ligne[2])

m = float(input("Entrez la masse de l'objet en kg : "))  # Saisie au clavier de la masse de la balle
g = 9.8  # intensité de la pesanteur
dt = t[1] - t[0]  # Détermination de l'intervalle de temps entre deux pointages

# Calcul des coordonnées des vecteurs vitesse

vx = [(x[i+1] - x[i-1]) / (2 * dt) for i in range(1, len(t)-1)]  # la vitesse n'est pas calculable à la première et à la dernière position
vy = [(y[i+1] - y[i-1]) / (2 * dt) for i in range(1, len(t)-1)]  # même remarque
v = [(vx[i]**2 + vy[i]**2)**0.5 for i in range(len(vx))]

# Calcul des énergies
    
Ep = [m * g * val for val in y[1:-1:]]
Ec = [0.5 * m * val**2 for val in v]
Em = [Ep[i] + Ec[i] for i in range(len(Ep))]

# Calcul des coordonnées des vecteurs variation de vitesse
"""Les listes en abscisses et ordonnées doivent avoir le même nombre de termes :
    on supprime le premier et le dernier terme de cette liste"""
    
plt.close()
plt.plot(t[1:-1:], Ep, "b+", label = "Énergie potentielle")
plt.plot(t[1:-1:], Ec, "r+", label = "Énergie cinétique")
plt.plot(t[1:-1:], Em, "g+", label = "Énergie mécanique")
plt.title("Évolution des énergies au cours du temps")
plt.xlabel("t (s)")
plt.ylabel("Énergies en J")
plt.grid()
plt.legend()
plt.show()
