#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Oct 14 12:02:26 2020

@author: xofe
"""
import matplotlib.pyplot as plt  # Bibliothèque graphique pour tracer les courbes et placer les points de mesure
from scipy.optimize import curve_fit  # Importation de la fonction de recherche du modèle.
from tkinter.filedialog import askopenfilename
import numpy as np

def Rel_modele(pente, frequence):
    U = pente * frequence
    return(U)

# ouvre une fenêtre pour charger le fichier csv issu des pointages NE PAS MODIFIER
nom_CSV = askopenfilename(filetypes =(("Fichier CSV", "*.csv"),("Fichier Texte","*.txt"),("Tous les fichiers","*.*")),title = "Choisir un fichier")

# IMPORTATION DES LISTES DE FRÉQUENCE ET USEUIL
"""ATTENTION : le fichier de données csv doit impérativement être modifié en amont afin d'utiliser
le point . comme séparateur décimal (pas la virgule)
On adapte ensuite le caractère délimitant les champs de données : ici le point-virgule ;"""
freq, Useuil = np.loadtxt(nom_CSV, unpack = True, delimiter = ';',skiprows=1, usecols=(0,1))
# f et Useuil sont deux listes contenant les valeurs de la fréquence et de la tension de seuil pour chaque mesure

coefficients = curve_fit(Rel_modele, freq, Useuil)
coeffDir = coefficients[0][0]
freq_mod = np.linspace(0., 7.e14, 101)
modele = [Rel_modele(coeffDir, val) for val in freq_mod]

plt.figure(1)
plt.plot(freq, Useuil, "r+", label = "Points expérimentaux")
plt.plot(freq_mod, modele, label = f"Modélisation : Useuil = {coeffDir:.3e} x f")
plt.xlabel("f (Hz)")
plt.ylabel("Useuil")
plt.legend()
plt.grid()
plt.show()

"""Calcul des écarts entre les points expérimentaux et le modèle et tracé du graphique correspondant
On calcule pour chaque point expérimental l'écart avec le modèle : Delta Useuil = Useuil expé - Useuil modèle
On place ces écarts sur un graphique, avec comme référence la ligne 0"""

deltaUseuil = [Useuil[i] - Rel_modele(coeffDir, freq[i]) for i in range(len(Useuil))]
ref = []
for i in range(len(Useuil)):
    ref.append(0)

plt.figure(2)
plt.plot(freq, ref, color = "blue", label = "Référence")
plt.plot(freq, deltaUseuil, "r+", label = "Écart avec le modèle")
plt.xlabel("f (Hz)")
plt.ylabel("Delta Useuil (V)")
plt.legend()
plt.grid()
plt.show()

"""Calcul de la valeur de la constante de Planck"""
e = 1.602e-19  # Définition de la valeur de la charge élémentaire
hTheo = 6.63e-34
hExpe = e * coeffDir
ecartRel = abs(hTheo - hExpe) / hTheo * 100
print(f"Valeur expérimentale de la constante de Planck {hExpe:.3e} J.s")
print(f"Écart relatif : e={ecartRel:.1f} %")
