#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Fri Feb 14 08:57:58 2020

@author: xofe
"""

import matplotlib.pyplot as plt
import numpy as np

e = 1.6e-19  # Charge élémentaire en coulombs
k = 9.e9  # Constante dans l'expression de la loi de Coulomb
nomsCharges = ["A", "B", "C", "D"]
N = 0

"""Création d'une grille pour la représentation du champ de vecteurs"""
X = np.linspace(-0.05, 0.05, 101)
Y = np.linspace(-0.05, 0.05, 101)
XX, YY = np.meshgrid(X, Y)
"""-------------------------------------------------------------"""

"""Saisie du nombre de charges ponctuelles"""
while (N < 1) or (N > 4):
    N = int(input("Entrez le nombre de charges ponctuelles (entre 1 et 4) : "))
    if (N < 1) or (N > 4):
        print("Saisie non valide, recommencez.")
"""----------------------------------------------------------------"""

"""Initialisation des coordonnées des charges avant saisie"""
xi = np.array([1., 1., 1., 1.])
yi = np.array([1., 1., 1., 1.])
ni = np.array([])  # Nombre de charges élémentaires de chaque particule
qi = np.array([])  # Charges des partiucles
"""------------------------------------------------------------"""

"""Saisie des coordonnées des charges ponctuelles et de leur charge"""
for i in range(N):
    while (xi[i] < -0.05) or (xi[i] > 0.05):
        xi[i] = float(input("Entrez l'abscisse de la charge ponctuelle " +
                            nomsCharges[i] + " entre -0.05 et 0.05 : "))
        if (xi[i] < -0.05) or (xi[i] > 0.05):
            print("Coordonnée hors grille, ressaisissez l'abscisse")
    while (yi[i] < -0.05) or (yi[i] > 0.05):
        yi[i] = float(input("Entrez l'ordonnée de la charge ponctuelle " +
                            nomsCharges[i] + " entre -0.05 et 0.05 : "))
        if (yi[i] < -0.05) or (yi[i] > 0.05):
            print("Coordonnée hors grille, ressaisissez l'ordonnée")
    ni = np.append(ni, int(input(
        "Entrez le nombre de charges ponctuelles portées par " + nomsCharges[i] + " : ")))
qi = ni * e  # Calcul des charges en coulombs

"""Détermination des distances séparant chaque point de la grille de chacune des charges"""
ri = [0., 0., 0., 0.]
for i in range(N):
    ri[i] = ((XX - xi[i])**2 + (YY - yi[i])**2)**0.5
"""-------------------------------------------------------------------------------------"""

"""Calcul des potentiels créés par chaque charge en tout point de la grille"""
Ui = [0., 0., 0., 0.]
for i in range(N):
    Ui[i] = k * qi[i] / ri[i]
"""--------------------------------------------------------------"""

"""Calcul du champ résultant"""
U = Ui[0]
for i in range(1, N):
    U = U + Ui[i]
"""-----------------------------------------------------------"""

"""Représentation du champ vectoriel"""
# plt.scatter(XX, YY, marker = ".", color = "k", s = 10, linewidths = 0.25)  # Matérialisation de la grille
plt.axis("equal")  # Repère orthonormé
""" Ci-dessous, on représente le champ de vecteurs
Adapter si besoin l'échelle : valeur scale si les vecteurs sont trop longs ou trop courts
Plus la valeur scale est élevée, plus les vecteurs sont courts et inversement."""
plt.pcolormesh(XX, YY, U, label="Équipotentielles")
for i in range(N):
    plt.scatter(xi[i], yi[i], marker="o", color="r",
                s=25)  # On place la charge
    plt.text(xi[i] + 0.00025, yi[i] + 0.00025,
             nomsCharges[i] + "," + str(ni[i]) + "e", color="r")
plt.legend()  # Affichage de la légende
plt.grid()
plt.show()  # Affichage de la fenêtre graphique
    plt.text(xi[i] + 0.00025, yi[i] + 0.00025,
             nomsCharges[i] + "," + str(ni[i]) + "e", color="r")
plt.legend()  # Affichage de la légende
plt.grid()
plt.show()  # Affichage de la fenêtre graphique
